#include <iostream>
#include <vector>
#include <set>
#include <list>
#include <map>
#include <queue>
#include <string>
#include <algorithm>
#include <iomanip>
#include <fstream>
#include <cmath>

#define ll long long
#define  ld long double
#define INF 10e+9
using namespace std;


/*** АЛГЕБРА ***/


// Sieve of Eratosthenes - O(n) vector <ll> primes(ll n)
vector<ll> primes(ll n)
{
    ll lp[n + 1];
    fill(lp, lp + n, 0);
    vector<ll> pr;
    for (ll i = 2; i <= n; ++i)
    {
        if (lp[i] == 0)
        {
            lp[i] = i;
            pr.push_back(i);
        }
        for (ll j = 0; (j < pr.size()) && (pr[j] <= lp[i]) && (i * pr[j] <= n); ++j)
        {
            lp[i * pr[j]] = pr[j];
        }
    }
    return pr;
}

ll gcd(ll a, ll b)
{
    return b != 0 ? gcd(b, a % b) : a;
}

/*
 * a*x + b*y = gcd(a, b)
 */
ll ext_gcd(ll a, ll b, ll &x, ll &y)
{
    if (b == 0)
    {
        x = 1;
        y = 0;
        return a;
    }
    ll g = ext_gcd(b, a % b, y, x);
    y -= a / b * x;
    return g;
}

ll lcm(ll a, ll b)
{
    return a / gcd(a, b) * b;
}

ll fibonacci(ll n)
{
// n=92 - max
    return ((pow((1 + sqrt(5)) / 2, n) - pow((1 - sqrt(5)) / 2, n)) / sqrt(5));
}


/*** ГЕОМЕТРИЯ ***/


ld EPS = 1e-5;

vector<pair<ld, ld>> circleLineCross(ld r, ld a, ld b, ld c)
{
    vector<pair<ld, ld>> out(0);
    ld x0 = -a * c / (a * a + b * b), y0 = -b * c / (a * a + b * b);
    if (c * c > r * r * (a * a + b * b) + EPS)
        return out;
    else if (abs(c * c - r * r * (a * a + b * b)) < EPS)
    {
        out.emplace_back(pair<ld, ld>(x0, y0));
        return out;
    }
    else
    {
        ld d = r * r - c * c / (a * a + b * b);
        ld mult = sqrt(d / (a * a + b * b));
        ld ax, ay, bx, by;
        ax = x0 + b * mult;
        bx = x0 - b * mult;
        ay = y0 - a * mult;
        by = y0 + a * mult;
        out.emplace_back(pair<ld, ld>(ax, ay));
        out.emplace_back(pair<ld, ld>(bx, by));
        return out;
    }
}


/*** ГРАФЫ ***/

/* DFS - O(n + m)
 * vector<bool> - the vector of visited vertices must be of size g.size() and filled with false
 */
void dfs(vector<vector<ll>> &g, vector<bool> &used, ll v)
{
    used[v] = true;
    for (auto i = g[v].begin(); i != g[v].end(); ++i)
    {
        if (!used[*i])
        {
            dfs(g, used, *i);
        }
    }
}

/* BFS - O(n + m)
 * vector<bool> - the vector of visited vertices must be of size g.size() and filled with false
 */
void bfs(vector<vector<ll>> &g, vector<bool> &used, ll v)
{
    queue<int> q;
    vector<int> d(g.size()), p(g.size());
    q.push(v);
    used[v] = true;
    p[v] = -1;
    while (!q.empty())
    {
        ll s = q.front();
        q.pop();
        for (ll i = 0; i < g[s].size(); ++i)
        {
            ll to = g[s][i];
            if (!used[to])
            {
                used[to] = true;
                q.push(to);
                d[to] = d[s] + 1;
                p[to] = s;
            }
        }
    }
}

/* Dijkstra - O(n * log(m))
 * vector<vector<pair<ll, ll>>> – adjacency matrix
 */
vector<ll> dijkstra(vector<vector<pair<ll, ll>>> &g, ll from)
{
    vector<ll> d(g.size(), INF), p(g.size());
    d[from] = 0;
    set<pair<ll, ll>> q;
    q.insert(make_pair(d[from], from));
    while (!q.empty())
    {
        ll v = q.begin()->second;
        q.erase(q.begin());
        for (ll j = 0; j < g[v].size(); ++j)
        {
            ll to = g[v][j].first, len = g[v][j].second;
            if (d[v] + len < d[to])
            {
                q.erase(make_pair(d[to], to));
                d[to] = d[v] + len;
                p[to] = v;
                q.insert(make_pair(d[to], to));
            }
        }
    }
    return d;
}

/* Floyd - O(n^3)
 * vector<vector<ll>> - graph. Important conditions: where no edges = INF and g[i][i] = 0
 */
void floyd(vector<vector<ll>> &g)
{
    ll n = g.size();
    for (ll k = 0; k < n; ++k)
    {
        for (ll i = 0; i < n; ++i)
        {
            for (ll j = 0; j < n; ++j)
            {
                if (g[i][k] < INF && g[k][j] < INF)
                {
                    g[i][j] = min(g[i][j], g[i][k] + g[k][j]);
                }
            }
        }
    }
}
/* Max Flow
 * source - 0, drain - n-1
 */
ll max_flow(vector<vector<ll>> &g)
{
    vector<vector<ll>> f(g.size(), vector<ll>(g.size()));
    while (true)
    {
        vector<ll> from(g.size(), -1);
        vector<ll> q(g.size());
        ll h = 0, t = 0;
        q[t++] = 0;
        from[0] = 0;
        for (ll cur; h < t;)
        {
            cur = q[h++];
            for (ll v = 0; v < g.size(); v++)
                if (from[v] == -1 && g[cur][v] - f[cur][v] > 0)
                {
                    q[t++] = v;
                    from[v] = cur;
                }
        }

        if (from[g.size() - 1] == -1)
            break;

        ll cf = INF;
        for (ll cur = g.size() - 1; cur != 0;)
        {
            ll prev = from[cur];
            cf = min(cf, g[prev][cur] - f[prev][cur]);
            cur = prev;
        }

        for (int cur = g.size() - 1; cur != 0;)
        {
            int prev = from[cur];
            f[prev][cur] += cf;
            f[cur][prev] -= cf;
            cur = prev;
        }
    }
    int flow = 0;
    for (int i = 0; i < g.size(); ++i)
        if (g[0][i])
        {
            flow += f[0][i];
        }

    return flow;
}

/*** СТРОКИ ***/

// Prefix-function - O(n)
vector<ll> prefix(string s)
{
    ll n = s.length();
    vector<ll> p(n);
    for (ll i = 1; i < n; ++i)
    {
        ll j = p[i - 1];
        while (j > 0 && s[i] != s[j])
        {
            j = p[j - 1];
        }
        if (s[i] == s[j])
        {
            ++j;
        }
        p[i] = j;
    }
    return p;
}

// Z-function - O(n)
vector<ll> z_function(string s)
{
    ll n = s.length();
    vector<ll> z(n);
    for (ll i = 1, l = 0, r = 0; i < n; ++i)
    {
        if (i <= r)
        {
            z[i] = min(r - i + 1, z[i - l]);
        }
        while (i + z[i] < n && s[z[i]] == s[i + z[i]])
        {
            ++z[i];
        }
        if (i + z[i] - 1 > r)
        {
            l = i, r = i + z[i] - 1;
        }
    }
    return z;
}

// BOR – O(m)
struct vertex
{
    int next[33]; // 33 - alphabet size
    bool leaf;
};
const ll NMAX = 10e+6;
vertex t[NMAX + 1]; // NMAX - max words length
// memset(t[0].next, 255, sizeof t[0].next); - initialization
int sz = 1;

void add_string(const string &s)
{
    ll v = 0;
    for (char i : s)
    {
        char c = i - 'a'; // depending on the alphabet
        if (t[v].next[c] == -1)
        {
            memset(t[sz].next, 255, sizeof t[sz].next);
            t[v].next[c] = sz++;
        }
        v = t[v].next[c];
    }
    t[v].leaf = true;
}

/*** MAIN ***/

int main()
{
    cin.tie(nullptr);
    std::istream::sync_with_stdio(false);

    ll k, n, c;
    cin >> k >> n >> c;
    cout << (k * n) - (c * k);

    return 0;
}